@@ -2,11 +2,14 @@
  *                   Materials Object Library                  *
  *     Class MatOoLbox : declaration for materials toolbox     *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.4.0                   *
+ *                   GNU/linux version 2.6.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2005,2006,2007,2008 COLLARD Christophe
- * copyright © 2005,2006,2007,2008 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2005,2006,2007,2008,2010 COLLARD Christophe
+ * copyright © 2005,2006,2007,2008,2010 Centre National de la Recherche Scientifique
+ * copyright © 2005,2006,2007,2008,2010 Arts et Métiers ParisTech
+ * copyright © 2005,2006,2007 Université de Valenciennes et du Hainaut-Cambrésis
+ * copyright © 2005,2006,2007,2008,2010 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
@@ -40,11 +43,14 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2007, 2008 Christophe COLLARD \n
-            copyright \htmlonly &#169; 2005, 2006, 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2007, 2008, 2010 Christophe COLLARD \n
+            copyright \htmlonly &#169; 2005, 2006, 2007, 2008, 2010 Centre National de la Recherche Scientifique \endhtmlonly \n
+	    copyright \htmlonly &#169; 2005, 2006, 2007, 2008, 2010 Arts et M&#233;tiers ParisTech \endhtmlonly \n
+	    copyright \htmlonly &#169; 2005, 2006, 2007 Universit&#233; de Valenciennes et du Hainaut Cambr&#233;sis \endhtmlonly \n
+            copyright \htmlonly &#169; 2005, 2006, 2007, 2008, 2010 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
-    \version 2.4.0
-    \date 2005-2010
+    \version 2.6.0
+    \date 2005-2011
     \bug none
     \warning none
 */
@@ -181,7 +187,7 @@ tensor2<T> constitutive_equation (const tensor_type<T>& T4, const tensor2<T>& T2
 //----------------------------------------------------------------------------------------------------------------------------
 {
   // dS_ij = L_ijkl dE_kl - M_ij dT
-  tensor2<T> tsr =& (T4 || str);
+  tensor2<T> tsr = (T4 || str);
 
   if (sgn == 1) tsr += T2 * To;
   else if (sgn == -1) tsr-= T2 * To;
