@@ -2,11 +2,14 @@
  *                   Material Object Library                   *
  *     Class TII : declaration for TII interaction tensor      *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.4.0                   *
+ *                   GNU/linux version 2.6.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2005,2006,2008,2009 COLLARD Christophe
  * copyright © 2006 PARGUEZ Cristelle
+ * copyright © 2005,2006,2008,2009 Centre National de la Recherche Scientifique
+ * copyright © 2005,2006,2008,2009 Arts et Métiers ParisTech
+ * copyright © 2005,2006 Université de Valenciennes et du Hainaut-Cambrésis
  * copyright © 2005,2006,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2005,2006 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
@@ -55,11 +58,14 @@
     (see Omar Fassi-Fehri - Th&#232;se de Doctorat d'Etat, ISGMP, LPMM - 1985). \n
 
     \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2008, 2009 Christophe COLLARD \n
+            copyright \htmlonly &#169; 2005, 2006, 2008, 2009 Centre National de la Recherche Scientifique \endhtmlonly \n
+	    copyright \htmlonly &#169; 2005, 2006, 2008, 2009 Arts et M&#233;tiers ParisTech \endhtmlonly \n
+	    copyright \htmlonly &#169; 2005, 2006 Universit&#233; de Valenciennes et du Hainaut Cambr&#233;sis \endhtmlonly \n
             copyright \htmlonly &#169; \endhtmlonly 2006 Cristelle PARGUEZ \n
             copyright \htmlonly &#169; 2005, 2006, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
-    \version 2.4.0
-    \date 2005-2010
+    \version 2.6.0
+    \date 2005-2011
     \bug none
     \warning none
 */
@@ -92,6 +98,10 @@
 #include "MOL++/tensors4.h"
 #endif
 
+#if !defined(__SYMTENSOR4_H)
+#include "MOL++/symtensors4.h"
+#endif
+
 #if !defined(__INTEGRATION_H)
 #include "MOL++/integration.h"
 #endif
@@ -198,7 +208,7 @@ tensor4<T> TII<T>::ellipsoid (const tensor_type<T>& L, const vector<T>& geometry
 	  khi[1] = Khi(i,j,1);
 	  khi[2] = scaling1 * Khi(i,j,2);
 	  khi[3] = scaling2 * Khi(i,j,3);
-	  M = (khi | L) * khi; // M(p,q) = L(p,k,q,l) * khi[k] * khi[l]
+	  M = (khi |  L) * khi; // M(p,q) = L(p,k,q,l) * khi[k] * khi[l]
 	  M = gauss (M);       // (L(i,k,j,l) * khi[k] * khi[l])^(-1)
 	  T wi_wj_sin_xi = wi_sin_xi * Itg2.weight(j);
 	
