@@ -2,12 +2,17 @@
  *                   Materials Object Library                  *
  *              Class isotropic_elasticity_tensor              *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.4.0                   *
+ *                   GNU/linux version 2.6.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2002,2003,2004,2005,2006,2008 COLLARD Christophe
+ * copyright © 2002,2003,2004,2005,2006,2008,2011 COLLARD Christophe
+ * copyright © 2002,2003,2004,2005,2006,2008,2011 Centre National de la Recherche Scientifique
+ * copyright © 2002,2003,2004,2005,2006,2008,2011 Arts et Métiers ParisTech
+ * copyright © 2002,2003,2004,2005,2006 Université de Valenciennes et du Hainaut-Cambrésis
  * copyright © 2002,2003,2004,2005,2006,2008 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2002,2003,2004,2005,2006 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
+ * copyright © 2011 Laboratoire d'Etude des Microstructures et de Mécanique des Matériaux (LEM3 - CNRS)
+ * copyright © 2011 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*! \namespace materiol
@@ -91,11 +96,16 @@
     \hline
     \end{tabular}} \f$
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2008 Christophe COLLARD \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2008, 2011 Christophe COLLARD \n
+            copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2008, 2011 Centre National de la Recherche Scientifique \endhtmlonly \n
+	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2008, 2011 Arts et M&#233;tiers ParisTech \endhtmlonly \n
+	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006 Universit&#233; de Valenciennes et du Hainaut Cambr&#233;sis \endhtmlonly \n
             copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
-    \version 2.4.0
-    \date 2002-2010
+	    copyright \htmlonly &#169; 2011 Laboratoire d'Etude des Microstructures et de MM&#233;canique des MatM&#233;riaux (LEM3 - CNRS) \endhtmlonly \n
+            copyright \htmlonly &#169; 2011 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
+    \version 2.6.0
+    \date 2002-2011
     \bug none
     \warning none
 */
@@ -108,6 +118,10 @@
 #define _isotropic_elasticity_tensors_h
 
 
+#if !defined (__STDLIB_H)
+#include <stdlib.h>
+#endif
+
 #if !defined (__IOSTREAM_H)
 #include <iostream>
 #endif
