@@ -2,12 +2,15 @@
  *                   Materials Object Library                  *
  * Class isotropic_tensor : declaration for isotropic material *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.4.0                   *
+ *                   GNU/linux version 2.6.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2002,2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2002,2003,2004,2005,2006,2007,2008,2009,2010 COLLARD Christophe
  * copyright © 2006 PARGUEZ Cristelle
- * copyright © 2002,2003,2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2002,2003,2004,2005,2006,2007,2008,2009,2010 Centre National de la Recherche Scientifique
+ * copyright © 2002,2003,2004,2005,2006,2007,2008,2009,2010 Arts et Métiers ParisTech
+ * copyright © 2002,2003,2004,2005,2006,2007 Université de Valenciennes et du Hainaut-Cambrésis
+ * copyright © 2002,2003,2004,2005,2006,2007,2008,2009,2010 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2002,2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
@@ -44,12 +47,15 @@
     Let \f$ \lambda \f$ and \f$ \mu \f$ be two constants. We define a \f$ 4^{th} \f$ order isotropic tensor \f$ \boldsymbol{C} \f$ through \f$ \lambda \f$ and \f$ \mu \f$ by \n
     \f$ C_{ijkl} = \lambda \delta_{ij} \delta_{kl} + \mu (\delta_{ik} \delta_{jl} + \delta_{il} \delta_{jk}) \f$
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Christophe COLLARD \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Christophe COLLARD \n
             copyright \htmlonly &#169; \endhtmlonly 2006 Cristelle PARGUEZ \n
-            copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
+            copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Centre National de la Recherche Scientifique \endhtmlonly \n
+	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Arts et M&#233;tiers ParisTech \endhtmlonly \n
+	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Universit&#233; de Valenciennes et du Hainaut Cambr&#233;sis \endhtmlonly \n
+            copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
-    \version 2.4.0
-    \date 2002-2010
+    \version 2.6.0
+    \date 2002-2011
     \bug none
     \warning none
 */
@@ -90,10 +96,22 @@
 #include "MOL++/matrix.h"
 #endif
 
-#if !defined(__TENSOR4_H)
+#if !defined(__TENSORS2_H)
+#include "MOL++/tensors2.h"
+#endif
+
+#if !defined(__SYMTENSORS2_H)
+#include "MOL++/symtensors2.h"
+#endif
+
+#if !defined(__TENSORS4_H)
 #include "MOL++/tensors4.h"
 #endif
 
+#if !defined(__SYMTENSORS4_H)
+#include "MOL++/symtensors4.h"
+#endif
+
 using namespace std;
 using namespace mol;
 
@@ -113,10 +131,12 @@ template <class T> class isotropic_tensor
     isotropic_tensor (string = "");  // default constructor
     isotropic_tensor (T, T, string = "");
     isotropic_tensor (const vector<T>&, string = "");
-    isotropic_tensor (const tensor4<T>&, string = "");  // cast convertion
+    isotropic_tensor (const tensor4<T>&, string = "");     // cast convertion
+    isotropic_tensor (const symtensor4<T>&, string = "");  // cast convertion
     ~isotropic_tensor () {}  // destructor
 
     operator tensor4<T> () const; // cast operator : isotropic_tensor -> tensor4
+    operator symtensor4<T> () const; // cast operator : isotropic_tensor -> symtensor4
 
     void name(string);  // computes tensor's name
     string name();      // returns tensor's name
@@ -138,22 +158,27 @@ template <class T> class isotropic_tensor
     template <class Tf> friend isotropic_tensor<Tf> operator || (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);  // P_ijkl = T_ijpq R_pqkl 
     isotropic_tensor<T>& operator += (const isotropic_tensor<T>&);  // overloads += operator for isotropic tensors
     isotropic_tensor<T>& operator -= (const isotropic_tensor<T>&);  // overloads -= operator for isotropic tensors
+
     // operations with scalars
     template <class Tf> friend isotropic_tensor<Tf> operator * (const isotropic_tensor<Tf>&, const Tf&);
     template <class Tf> friend isotropic_tensor<Tf> operator * (const Tf&, const isotropic_tensor<Tf>&);
     isotropic_tensor<T>& operator *= (const T&);
+
     // operations withs vectors
     template <class Tf> friend tensor3<Tf> operator * (const isotropic_tensor<Tf>&, const vector<Tf>&);  // P_ijk = T_ijkl * V_l
     template <class Tf> friend tensor3<Tf> operator * (const vector<Tf>&, const isotropic_tensor<Tf>&);  // P_jkl = T_ijkl * V_i
     template <class Tf> friend tensor3<Tf> operator | (const isotropic_tensor<Tf>&, const vector<Tf>&);  // P_ijl = T_ijkl * V_k
     template <class Tf> friend tensor3<Tf> operator | (const vector<Tf>&, const isotropic_tensor<Tf>&);  // P_ikl = T_ijkl * V_j
     template <class Tf> friend tensor3<Tf> tensor_sum (const isotropic_tensor<Tf>&, const vector<Tf>&, int);  // P = T : v
+
     // operation with 2nd order tensor
-    template <class Tf> friend tensor2<Tf> operator || (const isotropic_tensor<Tf>&, const tensor2<Tf>&);  // P_ij = T_ijkl * M_kl
-    template <class Tf> friend tensor2<Tf> operator || (const tensor2<Tf>&, const isotropic_tensor<Tf>&);  // P_kl = M_ij * T_ijkl
+    template <class Tf> friend symtensor2<Tf> operator || (const isotropic_tensor<Tf>&, const tensor2<Tf>&);  // P_ij = T_ijkl * M_kl
+    template <class Tf> friend symtensor2<Tf> operator || (const tensor2<Tf>&, const isotropic_tensor<Tf>&);  // P_kl = M_ij * T_ijkl
+
     // operation with 3rd order tensor
     template <class Tf> friend tensor3<Tf> operator || (const isotropic_tensor<Tf>&, const tensor3<Tf>&);  // P_n,ij = T_ijkl R_n,kl
     template <class Tf> friend tensor3<Tf> operator || (const tensor3<Tf>&, const isotropic_tensor<Tf>&);  // P_n,ij = R_n,kl T_klij
+
     // operations with 4rd order tensor
     template <class Tf> friend tensor4<Tf> operator + (const isotropic_tensor<Tf>&, const tensor4<Tf>&);
     template <class Tf> friend tensor4<Tf> operator + (const tensor4<Tf>&, const isotropic_tensor<Tf>&);
@@ -163,15 +188,30 @@ template <class T> class isotropic_tensor
     template <class Tf> friend Tf operator | (const tensor4<Tf>&, const isotropic_tensor<Tf>&);
     template <class Tf> friend tensor4<Tf> operator || (const isotropic_tensor<Tf>&, const tensor4<Tf>&);
     template <class Tf> friend tensor4<Tf> operator || (const tensor4<Tf>&, const isotropic_tensor<Tf>&);
+
+    // operations with symmetric 4rd order tensor
+    template <class Tf> friend symtensor4<Tf> operator + (const isotropic_tensor<Tf>&, const symtensor4<Tf>&);
+    template <class Tf> friend symtensor4<Tf> operator + (const symtensor4<Tf>&, const isotropic_tensor<Tf>&);
+    template <class Tf> friend symtensor4<Tf> operator - (const isotropic_tensor<Tf>&, const symtensor4<Tf>&);
+    template <class Tf> friend symtensor4<Tf> operator - (const symtensor4<Tf>&, const isotropic_tensor<Tf>&);
+    template <class Tf> friend Tf operator | (const isotropic_tensor<Tf>&, const symtensor4<Tf>&);
+    template <class Tf> friend Tf operator | (const symtensor4<Tf>&, const isotropic_tensor<Tf>&);
+    template <class Tf> friend symtensor4<Tf> operator || (const isotropic_tensor<Tf>&, const symtensor4<Tf>&);
+    template <class Tf> friend symtensor4<Tf> operator || (const symtensor4<Tf>&, const isotropic_tensor<Tf>&);
+
     template <class Tf> friend bool operator == (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);  // compares 2 isotropic tensors
     template <class Tf> friend bool operator != (const isotropic_tensor<Tf>&, const isotropic_tensor<Tf>&);
     template <class Tf> friend bool operator == (const isotropic_tensor<Tf>&, const tensor4<Tf>&);
     template <class Tf> friend bool operator == (const tensor4<Tf>&, const isotropic_tensor<Tf>&);
     template <class Tf> friend bool operator != (const isotropic_tensor<Tf>&, const tensor4<Tf>&);
     template <class Tf> friend bool operator != (const tensor4<Tf>&, const isotropic_tensor<Tf>&);
+    template <class Tf> friend bool operator == (const isotropic_tensor<Tf>&, const symtensor4<Tf>&);
+    template <class Tf> friend bool operator == (const symtensor4<Tf>&, const isotropic_tensor<Tf>&);
+    template <class Tf> friend bool operator != (const isotropic_tensor<Tf>&, const symtensor4<Tf>&);
+    template <class Tf> friend bool operator != (const symtensor4<Tf>&, const isotropic_tensor<Tf>&);
 
     isotropic_tensor<T> inv () const;
-    template <class Tf> friend isotropic_tensor<Tf> change_basis (const matrix<Tf>&, const isotropic_tensor<Tf>&, bool); // for orthogonal matrix
+    template <class Tf> friend isotropic_tensor<Tf> change_orthonormal_basis (const matrix<Tf>&, const isotropic_tensor<Tf>&);
     template <class Tf> friend tensor4<Tf> change_basis (const matrix<Tf>&, const isotropic_tensor<Tf>&);
 
     template <class Tf> friend ostream& operator << (ostream&, const isotropic_tensor<Tf>&);
@@ -265,6 +305,28 @@ template <class T> isotropic_tensor<T>::isotropic_tensor (const tensor4<T>& t, s
 }
 
 
+/*!
+  \brief Constructor for cast conversion.
+
+  Converts a symmetric \f$ \displaystyle 4^{th} \f$ order tensor into an isotropic tensor.
+
+  \param st symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+  \param name tensor name
+*/
+
+//---------------------------------------------------------------------------------------------
+template <class T> isotropic_tensor<T>::isotropic_tensor (const symtensor4<T>& st, string name)
+//---------------------------------------------------------------------------------------------
+{
+  assert(st.dim1()==3 && st.dim3()==3);
+
+  Lambda = st(1,1,2,2);
+  Mu = st(1,2,1,2);
+  tensor_name = name;
+  assert ((tensor4<T>)(*this) == st);
+}
+
+
 /*!
   \brief Cast operator for \f$ \displaystyle 4^{th} \f$ order isotropic tensors.
 
@@ -290,6 +352,33 @@ template <class T> isotropic_tensor<T>::operator tensor4<T> () const
 
 
 
+/*!
+  \brief Cast operator for \f$ \displaystyle 4^{th} \f$ order isotropic tensors.
+
+  Converts an isotropic tensor into a symmetric \f$ \displaystyle 4^{th} \f$ order tensor.
+*/
+
+//---------------------------------------------------------------------
+template <class T> isotropic_tensor<T>::operator symtensor4<T> () const
+//---------------------------------------------------------------------
+{
+  assert(Lambda && Mu);
+
+  symtensor4<T> tsr (3);
+
+  for (int i=1; i<=3; i++)
+    { tsr (i,i,i,i) = 2 * Mu;
+      for (int j=1; j<=3; j++)
+	tsr (i,i,j,j) += Lambda;
+    }
+
+  tsr (1,2,1,2) = tsr (1,3,1,3) = tsr (2,3,2,3) = Mu;
+
+  return tsr;
+}
+
+
+
 /*!
   \brief Changes tensor name
 
@@ -755,20 +844,21 @@ template <class Tf> tensor3<Tf> tensor_sum (const isotropic_tensor<Tf>& C, const
   \return \f$ \displaystyle 2^{nd} \f$ order tensor \f$ Q \f$
 */
 
-//-----------------------------------------------------------------------------------------------
-template <class Tf> tensor2<Tf> operator || (const isotropic_tensor<Tf>& C, const tensor2<Tf>& t)
-//-----------------------------------------------------------------------------------------------
+//--------------------------------------------------------------------------------------------------
+template <class Tf> symtensor2<Tf> operator || (const isotropic_tensor<Tf>& C, const tensor2<Tf>& t)
+//--------------------------------------------------------------------------------------------------
 {
   assert (t.Rows() == 3);
   assert (t.Columns() == 3);
 
-  tensor2<Tf> mat_result(3,3,false);
-  Tf temp = C.Lambda * tr(t);
+  symtensor2<Tf> mat_result (3, 3, false);
+
+  Tf val = C.Lambda * tr(t);
   for (int i=1; i<=3; i++)
-  { for (int j=1; j<=3; j++)
-      mat_result(i,j) = C.Mu *(t(i,j) + t(j,i));
-    mat_result(i,i) += temp;
-  }
+    { for (int j=i; j<=3; j++)
+	mat_result(i,j) = C.Mu * (t(i,j) + t(j,i));
+      mat_result(i,i) += val;
+    }
 
   return mat_result;
 }
@@ -786,9 +876,9 @@ template <class Tf> tensor2<Tf> operator || (const isotropic_tensor<Tf>& C, cons
   \return \f$ \displaystyle 2^{nd} \f$ order tensor \f$ Q \f$
 */
 
-//-----------------------------------------------------------------------------------------------
-template <class Tf> tensor2<Tf> operator || (const tensor2<Tf>& t, const isotropic_tensor<Tf>& C)
-//-----------------------------------------------------------------------------------------------
+//--------------------------------------------------------------------------------------------------
+template <class Tf> symtensor2<Tf> operator || (const tensor2<Tf>& t, const isotropic_tensor<Tf>& C)
+//--------------------------------------------------------------------------------------------------
 {
   return (C || t);
 }
@@ -815,7 +905,7 @@ template <class Tf> tensor3<Tf> operator || (const isotropic_tensor<Tf>& C, cons
   tensor3<Tf> ts;
   ts.create(3);
   for (int n=1; n<=3; n++)
-    ts[n] =& (t[n] || C);
+    ts[n] = (t[n] || C);
 
   return ts;
 
@@ -863,10 +953,10 @@ template <class Tf> tensor4<Tf> operator + (const isotropic_tensor<Tf>& C, const
   tensor4<Tf> tsr(t);
   for (int i=1; i<=3; i++)
     for (int j=1; j<=3; j++)
-    { tsr(i,i,j,j)+=C.Lambda;
-      tsr(i,j,i,j)+=C.Mu;
-      tsr(i,j,j,i)+=C.Mu;
-    }
+      { tsr(i,i,j,j)+=C.Lambda;
+	tsr(i,j,i,j)+=C.Mu;
+	tsr(i,j,j,i)+=C.Mu;
+      }
 
   return tsr;
 }
@@ -914,10 +1004,11 @@ template <class Tf> tensor4<Tf> operator - (const isotropic_tensor<Tf>& C, const
   tensor4<Tf> tsr((Tf)-1*t);
   for (int i=1; i<=3; i++)
     for (int j=1; j<=3; j++)
-    { tsr(i,i,j,j)+=C.Lambda;
-      tsr(i,j,i,j)+=C.Mu;
-      tsr(i,j,j,i)+=C.Mu;
-    }
+      { tsr(i,i,j,j)+=C.Lambda;
+	tsr(i,j,i,j)+=C.Mu;
+	tsr(i,j,j,i)+=C.Mu;
+      }
+
   return tsr;
 }
 
@@ -943,11 +1034,10 @@ template <class Tf> tensor4<Tf> operator - (const tensor4<Tf>& t, const isotropi
   tensor4<Tf> tsr(t);
   for (int i=1; i<=3; i++)
     for (int j=1; j<=3; j++)
-    { tsr(i,i,j,j)-=C.Lambda;
-      tsr(i,j,i,j)-=C.Mu;
-      tsr(i,j,j,i)-=C.Mu;
-    }
-
+      { tsr(i,i,j,j)-=C.Lambda;
+	tsr(i,j,i,j)-=C.Mu;
+	tsr(i,j,j,i)-=C.Mu;
+      }
 
   return tsr;
 }
@@ -973,10 +1063,10 @@ template <class Tf> Tf operator | (const isotropic_tensor<Tf>& C, const tensor4<
   Tf sum=0;
   for (int i=1; i<=3; i++)
     for (int j=1; j<=3; j++)
-    { sum+=C.Lambda*t(i,i,j,j);
-      sum+=C.Mu*t(i,j,i,j);
-      sum+=C.Mu*t(i,j,j,i);
-    }
+      { sum += C.Lambda * t(i,i,j,j);
+	sum += C.Mu * t(i,j,i,j);
+	sum += C.Mu * t(i,j,j,i);
+      }
 
   return sum;
 }
@@ -1052,15 +1142,247 @@ template <class Tf> tensor4<Tf> operator || (const tensor4<Tf>& t, const isotrop
   assert (t.dim1() == 3 && (t.dim2() == 3) && (t.dim3() == 3) && (t.dim4() == 3));
 
   tensor4<Tf> tsr(3,3,3,3,false);
+
   for (int p=1; p<=3; p++)
     for (int q=1; q<=3; q++)
       for (int k=1; k<=3; k++)
-      {	for (int l=1; l<=3; l++)
-	  tsr(p,q,k,l) = C.Mu*(t(p,q,k,l)+t(p,q,l,k));
-	for (int i=1; i<=3; i++)
-	  tsr(p,q,k,k) += C.Lambda*t(p,q,i,i);
+	{ for (int l=1; l<=3; l++)
+	    tsr(p,q,k,l) = C.Mu*(t(p,q,k,l)+t(p,q,l,k));
+	  for (int i=1; i<=3; i++)
+	    tsr(p,q,k,k) += C.Lambda*t(p,q,i,i);
+	}
+
+  return tsr;
+}
+
+
+/*!
+  \brief Addition between a \f$ \displaystyle 4^{th} \f$ order isotropic tensor and a symmetric \f$ \displaystyle 4^{th} \f$ order tensor.
+
+  Let \f$ N \f$ be a symmetric \f$ \displaystyle 4^{th} \f$ order tensor. We compute \f$ N = C+t \f$ \n
+  \f$ N_{ijkl} = C_{ijkl} + t_{ijkl} \f$.
+
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+  \param t \f$ symmetric \displaystyle 4^{th} \f$ order tensor
+
+  \return symmetric \f$ \displaystyle 4^{th} \f$ order tensor \f$ N \f$
+*/
+
+//----------------------------------------------------------------------------------------------------
+template <class Tf> symtensor4<Tf> operator + (const isotropic_tensor<Tf>& C, const symtensor4<Tf>& t)
+//----------------------------------------------------------------------------------------------------
+{
+  assert (t.dim1() == 3 && t.dim3() == 3);
+
+  symtensor4<Tf> tsr (t);
+
+  for (int i=1; i<=3; i++)
+    { tsr (i,i,i,i) += 2 * C.Mu;
+      for (int j=1; j<=3; j++)
+	tsr (i,i,j,j) += C.Lambda;
+    }
+
+  tsr (1,2,1,2) += C.Mu;
+  tsr (1,3,1,3) += C.Mu;
+  tsr (2,3,2,3) += C.Mu;
+
+  return tsr;
+}
+
+
+/*!
+  \brief Addition between a symmetric \f$ \displaystyle 4^{th} \f$ order tensor and a \f$ \displaystyle 4^{th} \f$ order isotropic tensor.
+
+  Let \f$ N \f$ be a symmetric \f$ \displaystyle 4^{th} \f$ order tensor. We compute \f$ N = t+C \f$ \n
+  \f$ N_{ijkl} = C_{ijkl} + t_{ijkl} \f$.
+
+  \param t symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+
+  \return symmetric \f$ \displaystyle 4^{th} \f$ order tensor \f$ N \f$
+*/
+
+//----------------------------------------------------------------------------------------------------
+template <class Tf> symtensor4<Tf> operator + (const symtensor4<Tf>& t, const isotropic_tensor<Tf>& C)
+//----------------------------------------------------------------------------------------------------
+{
+  return (C + t);
+}
+
+
+/*!
+  \brief Subtraction between a \f$ \displaystyle 4^{th} \f$ order isotropic tensor and a symmetric \f$ \displaystyle 4^{th} \f$ order tensor.
+
+  Let \f$ N \f$ be a symmetric \f$ \displaystyle 4^{th} \f$ order tensor. We compute \f$ N = C-t \f$ \n
+  \f$ N_{ijkl} = C_{ijkl} - t_{ijkl} \f$
+
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+  \param t symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+
+  \return symmetric \f$ \displaystyle 4^{th} \f$ order tensor \f$ N \f$
+*/
+
+//----------------------------------------------------------------------------------------------------
+template <class Tf> symtensor4<Tf> operator - (const isotropic_tensor<Tf>& C, const symtensor4<Tf>& t)
+//----------------------------------------------------------------------------------------------------
+
+{
+  assert (t.dim1() == 3 && t.dim3() == 3);
+
+  symtensor4<Tf> tsr((Tf)-1*t);
+
+  for (int i=1; i<=3; i++)
+    { tsr (i,i,i,i) += 2 * C.Mu;
+      for (int j=1; j<=3; j++)
+	tsr (i,i,j,j) += C.Lambda;
+    }
+
+  tsr (1,2,1,2) += C.Mu;
+  tsr (1,3,1,3) += C.Mu;
+  tsr (2,3,2,3) += C.Mu;
+
+  return tsr;
+}
+
+
+/*!
+  \brief Subtraction between a symmetric \f$ \displaystyle 4^{th} \f$ order tensor and a \f$ \displaystyle 4^{th} \f$ order isotropic tensor.
+
+  Let \f$ N \f$ be a symmetric \f$ \displaystyle 4^{th} \f$ order tensor. We compute \f$ N = t-C \f$ \n
+  \f$ N_{ijkl} = t_{ijkl} - C_{ijkl} \f$.
+
+  \param t symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+
+  \return symmetric \f$ \displaystyle 4^{th} \f$ order tensor \f$ N \f$
+*/
+
+//----------------------------------------------------------------------------------------------------
+template <class Tf> symtensor4<Tf> operator - (const symtensor4<Tf>& t, const isotropic_tensor<Tf>& C)
+//----------------------------------------------------------------------------------------------------
+{
+  assert (t.dim1() == 3 && t.dim3() == 3);
+
+  symtensor4<Tf> tsr(t);
+
+  for (int i=1; i<=3; i++)
+    { tsr (i,i,i,i) -= 2 * C.Mu;
+      for (int j=1; j<=3; j++)
+	tsr (i,i,j,j) -= C.Lambda;
+    }
+
+  tsr (1,2,1,2) -= C.Mu;
+  tsr (1,3,1,3) -= C.Mu;
+  tsr (2,3,2,3) -= C.Mu;
+
+  return tsr;
+}
+
+
+/*!
+  \brief Doubly contracted product between a \f$ \displaystyle 4^{th} \f$ order isotropic tensor and a symmetric \f$ \displaystyle 4^{th} \f$ order tensor.
+
+  We compute \f$ C :: t = C_{ijkl} * t_{ijkl} \f$.
+
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+  \param t symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+
+  \return scalar \f$ C :: t \f$
+*/
+
+//----------------------------------------------------------------------------------------
+template <class Tf> Tf operator | (const isotropic_tensor<Tf>& C, const symtensor4<Tf>& t)
+//----------------------------------------------------------------------------------------
+{
+  assert (t.dim1() == 3 && t.dim3() == 3);
+
+  Tf sum=0;
+
+  for (int i=1; i<=3; i++)
+    for (int j=1; j<=3; j++)
+      { sum += C.Lambda * t(i,i,j,j);
+	sum += 2 * C.Mu * t(i,j,i,j);
       }
 
+  return sum;
+}
+
+
+/*!
+  \brief Doubly contracted product between a symmetric \f$ \displaystyle 4^{th} \f$ order tensor and a \f$ \displaystyle 4^{th} \f$ order isotropic tensor.
+
+  We compute \f$ t :: C = C_{ijkl} * t_{ijkl} \f$.
+
+  \param t symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+
+  \return scalar \f$ t :: C \f$
+*/
+
+//----------------------------------------------------------------------------------------
+template <class Tf> Tf operator | (const symtensor4<Tf>& t, const isotropic_tensor<Tf>& C)
+//----------------------------------------------------------------------------------------
+{
+  return (C|t);
+}
+
+
+/*!
+  \brief Contracted product between a \f$ \displaystyle 4^{th} \f$ order isotropic tensor and a symmetric \f$ \displaystyle 4^{th} \f$ order tensor.
+
+  Let \f$ N \f$ be a symmetric \f$ \displaystyle 4^{th} \f$ order tensor. We compute \f$ N = C : t \f$ \n
+  \f$ N_{ijkl} = C_{ijpq} * t_{pqkl} \f$.
+
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+  \param t symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+
+  \return symmetric \f$ \displaystyle 4^{th} \f$ order tensor \f$ N \f$
+*/
+
+//-----------------------------------------------------------------------------------------------------
+template <class Tf> symtensor4<Tf> operator || (const isotropic_tensor<Tf>& C, const symtensor4<Tf>& t)
+//-----------------------------------------------------------------------------------------------------
+{
+  assert (t.dim1() == 3 && t.dim3() == 3);
+
+  symtensor4<Tf> tsr (2 * C.Mu * t);
+
+  for (int i=1; i<=3; i++)
+    for (int p=1; p<=3; p++)
+      for (int q=p; q<=3; q++)
+	for (int k=1; k<=3; k++)
+	  tsr (i,i,p,q) += C.Lambda * t (k,k,p,q);
+
+  return tsr;
+}
+
+
+/*!
+  \brief Contracted product between a symmetric \f$ \displaystyle 4^{th} \f$ order tensor and a \f$ \displaystyle 4^{th} \f$ order isotropic tensor.
+
+  Let \f$ N \f$ be a symmetric \f$ \displaystyle 4^{th} \f$ order tensor. We compute \f$ N = t : C \f$ \n
+  \f$ N_{ijkl} = t_{ijpq} * C_{pqkl} \f$.
+
+  \param t symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+
+  \return symmetric \f$ \displaystyle 4^{th} \f$ order tensor \f$ N \f$
+*/
+
+//-----------------------------------------------------------------------------------------------------
+template <class Tf> symtensor4<Tf> operator || (const symtensor4<Tf>& t, const isotropic_tensor<Tf>& C)
+//-----------------------------------------------------------------------------------------------------
+{
+  assert (t.dim1() == 3 && t.dim3() == 3);
+
+  symtensor4<Tf> tsr (2 * C.Mu * t);
+
+  for (int i=1; i<=3; i++)
+    for (int j=i; j<=3; j++)
+      for (int p=1; p<=3; p++)
+	for (int k=1; k<=3; k++)
+	  tsr (i,j,p,p) += C.Lambda * t (i,j,k,k);
+
   return tsr;
 }
 
@@ -1180,6 +1502,84 @@ template <class Tf> bool operator != (const tensor4<Tf>& t, const isotropic_tens
 }
 
 
+/*!
+  \brief Compares a \f$ \displaystyle 4^{th} \f$ order isotropic tensor with a symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+  \param t symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+
+  \return TRUE if \f$ C = t \f$ and FALSE if \f$ C \neq t \f$
+*/
+
+//-------------------------------------------------------------------------------------------
+template <class Tf> bool operator == (const isotropic_tensor<Tf>& C, const symtensor4<Tf>& t)
+//-------------------------------------------------------------------------------------------
+{
+  assert (t.dim1() == 3 && t.dim3() == 3);
+
+  int result = true;
+
+  for (int i=1; i<=3; i++)
+    for (int j=i; j<=3; j++)
+      for (int k=1; k<=3; k++)
+	for (int l=k; l<=3; l++)
+	  result *= relative_error (C(i,j,k,l), t(i,j,k,l));
+
+  return result;
+}
+
+
+/*!
+  \brief Compares a symmetric \f$ \displaystyle 4^{th} \f$ order tensor with a \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+
+  \param t symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+
+  \return TRUE if \f$ t = C \f$ and FALSE if \f$ t \neq C \f$
+*/
+
+//-------------------------------------------------------------------------------------------
+template <class Tf> bool operator == (const symtensor4<Tf>& t, const isotropic_tensor<Tf>& C)
+//-------------------------------------------------------------------------------------------
+{
+  return (C == t);
+}
+
+
+/*!
+  \brief Compares a \f$ \displaystyle 4^{th} \f$ order isotropic tensor with a symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+  \param t symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+
+  \return TRUE if \f$ C \neq t \f$ and FALSE if \f$ C = t \f$
+*/
+
+//-------------------------------------------------------------------------------------------
+template <class Tf> bool operator != (const isotropic_tensor<Tf>& C, const symtensor4<Tf>& t)
+//-------------------------------------------------------------------------------------------
+{
+  return !(C == t);
+}
+
+
+/*!
+  \brief Compares a symmetric \f$ \displaystyle 4^{th} \f$ order tensor with a \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+
+  \param t symmetric \f$ \displaystyle 4^{th} \f$ order tensor
+  \param C \f$ \displaystyle 4^{th} \f$ order isotropic tensor
+
+  \return TRUE if \f$ t \neq C \f$ and FALSE if \f$ t = C \f$
+*/
+
+//-------------------------------------------------------------------------------------------
+template <class Tf> bool operator != (const symtensor4<Tf>& t, const isotropic_tensor<Tf>& C)
+//-------------------------------------------------------------------------------------------
+{
+  return !(C == t);
+}
+
+
 /*!
   \brief Computes the inverse of a \f$ \displaystyle 4^{th} \f$ order isotropic tensor.
 
@@ -1210,13 +1610,11 @@ template <class T> isotropic_tensor<T> isotropic_tensor<T>::inv () const
   \return \f$ C^\prime \f$ isotropic tensor in the new basis
 */
 
-//----------------------------------------------------------------------------------------------------------------------------
-template <class Tf> isotropic_tensor<Tf> change_basis (const matrix<Tf>& P, const isotropic_tensor<Tf>& tsr, bool Porthogonal)
-//----------------------------------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
+template <class Tf> isotropic_tensor<Tf> change_orthonormal_basis (const matrix<Tf>& P, const isotropic_tensor<Tf>& tsr)
+//----------------------------------------------------------------------------------------------------------------------
 {
-  assert (Porthogonal);
-  assert ((P.Rows() ==3) && (P.Columns() == 3));
-  assert (t(P) == gauss(P));
+  assert ((P.Rows() == 3) && (P.Columns() == 3));
   
   return tsr;
 }
