@@ -2,12 +2,14 @@
  *                   Material Object Library                   *
  *  Class loading : declaration for different loading dstrain  *
  *                      simula+@ensam.eu                       *
- *                   GNU/linux version 2.4.0                   *
+ *                   GNU/linux version 2.6.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2008 COLLARD Christophe
+ * copyright © 2008,2010 COLLARD Christophe
  * copyright © 2008 NICAISE Nicolas
- * copyright © 2008 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2008,2010 Centre National de la Recherche Scientifique
+ * copyright © 2008,2010 Arts et Métiers ParisTech
+ * copyright © 2008,2010 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  ***************************************************************/
 
 /*! \namespace materiol
@@ -40,11 +42,13 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2008 Christophe COLLARD \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2008, 2010 Christophe COLLARD \n
             copyright \htmlonly &#169; \endhtmlonly 2008 Nicolas NICAISE \n
-            copyright \htmlonly &#169; 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly
-    \version 2.4.0
-    \date 2008-2010
+            copyright \htmlonly &#169; 2008, 2010 Centre National de la Recherche Scientifique \endhtmlonly \n
+	    copyright \htmlonly &#169; 2008, 2010 Arts et M&#233;tiers ParisTech \endhtmlonly \n
+            copyright \htmlonly &#169; 2008, 2010 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly
+    \version 2.6.0
+    \date 2008-2011
     \bug none
     \warning none
 */
@@ -106,7 +110,7 @@ template <class T, template <class> class tensor_type> class loading
 
 //----------------------------------------------------
 template <class T, template <class> class tensor_type>
-loading<T, tensor_type>::loading(ifstream& file3)
+loading<T, tensor_type>::loading (ifstream& file3)
 //----------------------------------------------------
 { 
   string text, keyword, loading_type, end_crit;
@@ -131,13 +135,15 @@ tensor2<T> loading<T, tensor_type>::UT (const tensor_type <T>& L, T dE, int axis
   assert (axis == 11 || axis == 22 || axis ==33);
 
   axis /= 11;
-  matrix<T> Linv = gauss(symtensor2matrix(L));
-  T dSigma = dE / Linv(axis,axis);
-  vector<T> dotE(6);
-  for (int i=1; i<=6; i++)
-    dotE[i] = Linv(i, axis) * dSigma;
+  tensor_type<T> Linv = L.inv();
 
-  return vector2symtensor(dotE);
+  T dSigma = dE / Linv (axis, axis, axis, axis);
+  symtensor2<T> dotE (3);
+  for (int i=1; i<=3; i++)
+    for (int j=i; j<=3; j++)
+      dotE (i,j) = Linv (i, j, axis, axis) * dSigma;
+
+  return dotE;
 }
 
 
@@ -157,16 +163,17 @@ tensor2<T> loading<T, tensor_type>::PS (const tensor_type <T>& L, T dE, int axis
 //-------------------------------------------------------------------------------
 { assert (axis == 12 || axis == 13 || axis == 23);
 
-  if(axis == 12){ axis= 4;}
-  if(axis == 13){ axis= 5;}
-  if(axis == 23){ axis= 6;}
-  matrix<T> Linv = gauss(symtensor2matrix(L));
-  T dSigma = dE / Linv(axis,axis);
-  vector<T> dotE(6);
+  if (axis == 12) axis = 4;
+  if (axis == 13) axis = 5;
+  if (axis == 23) axis = 6;
+
+  matrix<T> Linv = gauss (symtensor2matrix (L));
+  T dSigma = dE / Linv (axis, axis);
+  vector<T> dotE (6);
   for (int i=1; i<=6; i++)
     dotE[i] = sqrt(2) * Linv(i, axis) * dSigma;
 
-  return vector2symtensor(dotE);
+  return vector2symtensor (dotE);
 }
 
 }
