@@ -3,11 +3,15 @@
  *         Class systems: declaration for slip sytems          *
  *                                    or martensitic variants  *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.4.0                  *
+ *                   GNU/linux version 2.6.0                  *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2008,2009 COLLARD Christophe
+ * copyright © 2008,2009,2011 COLLARD Christophe
+ * copyright © 2008,2009,2011 Centre National de la Recherche Scientifique
+ * copyright © 2008,2009,2011 Arts et Métiers ParisTech
  * copyright © 2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2011 Laboratoire d'Etude des Microstructures et de Mécanique des Matériaux (LEM3 - CNRS)
+ * copyright © 2011 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*! \namespace materiol
@@ -45,10 +49,14 @@
     the Schmid tensor for each system
     \sa Schmid_tensor
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2008, 2009 Christophe COLLARD \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2008, 2009, 2011 Christophe COLLARD \n
+            copyright \htmlonly &#169; 2008, 2009, 2011 Centre National de la Recherche Scientifique \endhtmlonly \n
+	    copyright \htmlonly &#169; 2008, 2009, 2011 Arts et M&#233;tiers ParisTech \endhtmlonly \n
             copyright \htmlonly &#169; 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
-    \version 2.4.0
-    \date 2008-2010
+	    copyright \htmlonly &#169; 2011 Laboratoire d'Etude des Microstructures et de MM&#233;canique des MatM&#233;riaux (LEM3 - CNRS) \endhtmlonly \n
+            copyright \htmlonly &#169; 2011 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
+    \version 2.6.0
+    \date 2008-2011
     \bug none
     \warning none
 */
@@ -60,6 +68,10 @@
 #ifndef _systems_h
 #define _systems_h
 
+#if !defined (__STDLIB_H)
+#include <stdlib.h>
+#endif
+
 #if !defined (__IOSTREAM_H)
 #include <iostream>
 #endif
