@@ -3,12 +3,16 @@
  * Class transversely_isotropic_elastic_tensor : for           *
  *  transversely isotropic elastic materials (in x3 direction) *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.4.0                   *
+ *                   GNU/linux version 2.6.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2008,2009 BERBENNI Stephane
- * copyright © 2009 COLLARD Christophe
+ * copyright © 2009,2011 COLLARD Christophe
+ * copyright © 2008,2009,2011 Centre National de la Recherche Scientifique
+ * copyright © 2008,2009,2011 Arts et Métiers ParisTech
  * copyright © 2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2011 Laboratoire d'Etude des Microstructures et de Mécanique des Matériaux (LEM3 - CNRS)
+ * copyright © 2011 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 
@@ -96,10 +100,14 @@
     \f$ c_{13} = c_{31} = c_{23} = c_{32} = 2  k \nu_{31} \f$. \n
 
     \author copyright \htmlonly &#169; 2008, 2009 St&#233;phane BERBENNI \endhtmlonly \n
-            copyright \htmlonly &#169; \endhtmlonly 2009 Christophe COLLARD \n
+            copyright \htmlonly &#169; \endhtmlonly 2009,2011 Christophe COLLARD \n
+	    copyright \htmlonly &#169; 2008, 2009, 2011 Centre National de la Recherche Scientifique \endhtmlonly \n
+	    copyright \htmlonly &#169; 2008, 2009, 2011 Arts et M&#233;tiers ParisTech \endhtmlonly \n
             copyright \htmlonly &#169; 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
-    \version 2.4.0
-    \date 2008-2010
+	    copyright \htmlonly &#169; 2011 Laboratoire d'Etude des Microstructures et de M&#233;canique des Mat&#233;riaux (LEM3 - CNRS) \endhtmlonly \n
+            copyright \htmlonly &#169; 2011 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
+    \version 2.6.0
+    \date 2008-2011
     \bug none
     \warning none
 */
@@ -165,8 +173,11 @@ template <class T> class transversely_isotropic_elastic_tensor : public transver
   public:
     transversely_isotropic_elastic_tensor (string name = "") : transversely_isotropic_tensor<T> (name) {};  // default constructor
     transversely_isotropic_elastic_tensor (T, T, T, T, T, string = "");
+    transversely_isotropic_elastic_tensor (const transversely_isotropic_tensor<T>&); // cast convertion
     ~transversely_isotropic_elastic_tensor () {}  // destructor
 
+    template <class Tf> friend bool operator == (const transversely_isotropic_elastic_tensor<Tf>&, const transversely_isotropic_elastic_tensor<Tf>&);
+    template <class Tf> friend bool operator != (const transversely_isotropic_elastic_tensor<Tf>&, const transversely_isotropic_elastic_tensor<Tf>&);
     template <class Tf> friend ostream& operator << (ostream&, transversely_isotropic_elastic_tensor<Tf>&);
 };
 
@@ -212,13 +223,51 @@ transversely_isotropic_elastic_tensor<T>::transversely_isotropic_elastic_tensor
 }
 
 
+/*!
+  \brief Constructor for cast conversion.
+
+  Converts a \f$ \displaystyle 4^{th} \f$ order transversely isotropic tensor into a transversely isotropic elastic tensor.
+
+  \param tensor \f$ \displaystyle 4^{th} \f$ order transversely isotropic tensor
+*/
+
+//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+template <class T>
+transversely_isotropic_elastic_tensor<T>::transversely_isotropic_elastic_tensor (const transversely_isotropic_tensor<T>& tensor) : transversely_isotropic_tensor<T> (tensor)
+//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+{
+  T c0 = pow (C11, 2) - pow (C12, 2);
+  T c1 = C11 * C33  -  pow (C13, 2);
+  E1 = E3 = (C33 * c0 +  2 * pow (C13, 2) * (C12 - C11));
+  E1 /= c1;
+  E3 /= c0;
+  nu12 = (C12 * C33 - pow (C13, 2)) / c1;
+  nu31 = (C11 * C13 - C12 * C13) / c0;
+  G13 = C66;
+}
+
+
+//---------------------------------------------------------------------------------------------------------------------------------------------
+template <class Tf> bool operator == (const transversely_isotropic_elastic_tensor<Tf>& t1, const transversely_isotropic_elastic_tensor<Tf>& t2)
+//---------------------------------------------------------------------------------------------------------------------------------------------
+{
+  bool err = relative_error (t1.E1, t2.E1);
+  err *= relative_error (t1.E3, t2.E3);
+  err *= relative_error (t1.nu12, t2.nu12);
+  err *= relative_error (t1.nu31, t2.nu31);
+  err *= relative_error (t1.G13, t2.G13);
+
+  return err;
+}
+
+
 //---------------------------------------------------------------------------------------------------
 template <class Tf> ostream& operator << (ostream& s, transversely_isotropic_elastic_tensor<Tf>& tsr)
 //---------------------------------------------------------------------------------------------------
 {
   s << tsr.tensor_name << endl;
   s << "Material constants : (" << tsr.E1 << ", " << tsr.E3 << ", " << tsr.nu12 << ", " << tsr.nu31 << ", " << tsr.G13 << ")" << endl;
-  s << (tensor4<Tf>) tsr;
+  s << tsr.mat;
   s << endl;
 
   return s;
