@@ -3,12 +3,16 @@
  * Class transversely_isotropic_tensor: declaration for        *
  *          transversely isotropic (in x3 direction) materials *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.4.0                   *
+ *                   GNU/linux version 2.6.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2008,2009 BERBENNI Stéphane
- * copyright © 2009 COLLARD Christophe
+ * copyright © 2009,2011 COLLARD Christophe
+ * copyright © 2008,2009,2011 Centre National de la Recherche Scientifique
+ * copyright © 2008,2009,2011 Arts et Métiers ParisTech
  * copyright © 2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2011 Laboratoire d'Etude des Microstructures et de Mécanique des Matériaux (LEM3 - CNRS)
+ * copyright © 2011 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*! \namespace materiol
@@ -61,10 +65,14 @@
 	and we get the following symmetries : \f$T_{ijkl} = T_{jikl} = T_{ijlk} = T_{klij} \f$.
 
     \author copyright \htmlonly &#169; \endhtmlonly 2008, 2009 Stephane BERBENNI \n
-            copyright \htmlonly &#169; \endhtmlonly 2009 Christophe COLLARD \n
-	    copyright \htmlonly &#169; 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
-    \version 2.4.0
-    \date 2008-2010
+            copyright \htmlonly &#169; \endhtmlonly 2009, 2011 Christophe COLLARD \n
+	    copyright \htmlonly &#169; 2009, 2010, 2011 Centre National de la Recherche Scientifique \endhtmlonly \n
+	    copyright \htmlonly &#169; 2009, 2010, 2011 Arts et M&#233;tiers ParisTech \endhtmlonly \n
+	    copyright \htmlonly &#169; 2008, 2009, 2011 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2011 Laboratoire d'Etude des Microstructures et de M&#233;canique des Mat&#233;riaux (LEM3 - CNRS) \endhtmlonly \n
+            copyright \htmlonly &#169; 2011 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
+    \version 2.6.0
+    \date 2008-2011
     \bug none
     \warning none
 */
@@ -77,6 +85,10 @@
 #define _transversely_isotropic_tensors_h
 
 
+#if !defined (__STDLIB_H)
+#include <stdlib.h>
+#endif
+
 #if !defined (__IOSTREAM_H)
 #include <iostream>
 #endif
@@ -105,8 +117,8 @@
 #include "MOL++/vectors.h"
 #endif
 
-#if !defined(__TENSORS4_H)
-#include "MOL++/tensors4.h"
+#if !defined(__SYMTENSORS4_H)
+#include "MOL++/symtensors4.h"
 #endif
 
 using namespace std;
@@ -116,12 +128,11 @@ namespace materiol
 {
 
 
-//========================================================================
-template <class T> class transversely_isotropic_tensor : public tensor4<T>
-//========================================================================
+//===========================================================================
+template <class T> class transversely_isotropic_tensor : public symtensor4<T>
+//===========================================================================
 {
-  using tensor4<T>::size;
-  using tensor4<T>::tsr;
+  using symtensor4<T>::mat;
 
   protected :
     T C11, C33, C66, C12, C13; // material constants : 5 with C66=(C11-C12)/2
@@ -133,7 +144,7 @@ template <class T> class transversely_isotropic_tensor : public tensor4<T>
     transversely_isotropic_tensor (string = "");  // default constructor
     transversely_isotropic_tensor (T, T, T, T, T, string = "");
     transversely_isotropic_tensor (const vector<T>&, string = "");
-    transversely_isotropic_tensor (const tensor4<T>&, string = "");  // cast convertion
+    transversely_isotropic_tensor (const tensor4<T>&, string = "");  // cast conversion
     ~transversely_isotropic_tensor () {}  // destructor
 
     string name(string = "");  // returns / computes tensor's name
@@ -152,18 +163,12 @@ template <class T> class transversely_isotropic_tensor : public tensor4<T>
 template <class T> void transversely_isotropic_tensor<T>::build_tensor ()
 //-----------------------------------------------------------------------
 {
-  if (!size)  // used for de derivated classes
-    { tsr = new tensor3<T> [size=3];
-      for (int i=0; i<size; i++)
-	tsr[i] =& tensor3<T> (size,size,size);
-    }
-
-  (*this)(1,1,1,1) = (*this)(2,2,2,2) = C11;
-  (*this)(3,3,3,3) = C33;
-  (*this)(1,2,1,2) = (*this)(1,2,2,1) = (*this)(2,1,1,2) = (*this)(2,1,2,1) = 0.5 * (C11 - C12);
-  (*this)(1,3,1,3) = (*this)(1,3,3,1) = (*this)(3,1,1,3) = (*this)(3,1,3,1) = (*this)(2,3,2,3) = (*this)(2,3,3,2) = (*this)(3,2,2,3) = (*this)(3,2,3,2) = C66;
-  (*this)(1,1,2,2) = (*this)(2,2,1,1) = C12;
-  (*this)(1,1,3,3) = (*this)(3,3,1,1) = (*this)(2,2,3,3) = (*this)(3,3,2,2) = C13;
+  mat(1,1) = mat(2,2) = C11;
+  mat(3,3) = C33;
+  mat(4,4) = 0.5 * (C11 - C12);
+  mat(5,5) = mat(6,6) = C66;
+  mat(1,2) = mat(2,1) = C12;
+  mat(1,3) = mat(3,1) = mat(2,3) = mat(3,2) = C13;
 }
 
 
@@ -176,9 +181,9 @@ template <class T> void transversely_isotropic_tensor<T>::build_tensor ()
   \param name tensor name
 */
 
-//----------------------------------------------------------------------------------------------
-template <class T> transversely_isotropic_tensor<T>::transversely_isotropic_tensor (string name)
-//----------------------------------------------------------------------------------------------
+//-----------------------------------------------------------------------------------------------------------------
+template <class T> transversely_isotropic_tensor<T>::transversely_isotropic_tensor (string name) : symtensor4<T>(3)
+//-----------------------------------------------------------------------------------------------------------------
 {
   C11 = C33 = C66 = C12 = C13 = 0;  // 5 coeff
   tensor_name = name;
@@ -198,10 +203,10 @@ template <class T> transversely_isotropic_tensor<T>::transversely_isotropic_tens
   \param name tensor name
 */
 
-//------------------------------------------------------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------------------------------------------------------
 template <class T>
-transversely_isotropic_tensor<T>::transversely_isotropic_tensor (T c11, T c33, T c66, T c12, T c13, string name) : tensor4<T>(3)
-//------------------------------------------------------------------------------------------------------------------------------
+transversely_isotropic_tensor<T>::transversely_isotropic_tensor (T c11, T c33, T c66, T c12, T c13, string name) : symtensor4<T>(3)
+//---------------------------------------------------------------------------------------------------------------------------------
 {
   C11 = c11;
   C33 = c33;
@@ -223,9 +228,9 @@ transversely_isotropic_tensor<T>::transversely_isotropic_tensor (T c11, T c33, T
   \param name tensor name
 */
 
-//----------------------------------------------------------------------------------------------------------------------------------
-template <class T> transversely_isotropic_tensor<T>::transversely_isotropic_tensor (const vector<T>& v, string name) : tensor4<T>(3)
-//----------------------------------------------------------------------------------------------------------------------------------
+//-------------------------------------------------------------------------------------------------------------------------------------
+template <class T> transversely_isotropic_tensor<T>::transversely_isotropic_tensor (const vector<T>& v, string name) : symtensor4<T>(3)
+//-------------------------------------------------------------------------------------------------------------------------------------
 {
   assert (v.dim() == 5);
 
@@ -253,13 +258,13 @@ template <class T> transversely_isotropic_tensor<T>::transversely_isotropic_tens
 template <class T> transversely_isotropic_tensor<T>::transversely_isotropic_tensor (const tensor4<T>& t, string name)
 //-------------------------------------------------------------------------------------------------------------------
 {
-  assert(t.dim1()==3 && t.dim2()==3 && t.dim3()==3 && t.dim4()==3);
+  assert(mat.nbRows() && mat.nbColumns());
 
-  C11 = t(1,1,1,1);
-  C33 = t(3,3,3,3);
-  C66 = t(2,3,2,3);
-  C12 = t(1,1,2,2);
-  C13 = t(1,1,3,3);
+  C11 = mat(1,1);
+  C33 = mat(3,3);
+  C66 = mat(6,6);
+  C12 = mat(1,2);
+  C13 = mat(1,3);
   tensor_name = name;
   build_tensor();
 
@@ -307,17 +312,20 @@ template <class T> vector<T> transversely_isotropic_tensor<T>::elastic_constants
 /*!
   \brief Computes the inverse of a \f$ \displaystyle 4^{th} \f$ order transversely isotropic tensor.
 
-  not implemented yet !
+  \return inverse of the tensor which is also a transversely isotropic tensor
 */
 
 //------------------------------------------------------------------------------------------
 template <class T> transversely_isotropic_tensor<T> transversely_isotropic_tensor<T>::inv ()
 //------------------------------------------------------------------------------------------
 {
-  exit(0); // not implemented yet
-  T val = 1 / ( (C11 - C12) * (C11 + 2*C12));
+  T det_inv = 1 / (C33 * (pow (C11, 2) - pow (C12, 2))  +  2 * pow (C13, 2) * (C12 - C11));
+  T C_11 = (C11 * C33  -  pow (C13, 2)) * det_inv;
+  T C_33 = (pow (C11, 2) - pow (C12, 2)) * det_inv;
+  T C_12 = (pow (C13, 2) - C12 * C33) * det_inv;
+  T C_13 = (C12 * C13 - C11 * C13) *det_inv;
 
-  return transversely_isotropic_tensor<T> ( (C11+C12)*val, 0.25/C66, -C12 * val ); // l'encodage (symtensor -> matrix) utilise n'est pas celui de la doc => laisser le 0.25 / C66 !!
+  return transversely_isotropic_tensor<T> (C_11, C_33, 0.25/C66, C_12, C_13); // l'encodage (symtensor -> matrix) utilise n'est pas celui de la doc => laisser le 0.25 / C66 !!
 }
 
 
