@@ -2,11 +2,13 @@
  *                   Materials Object Library                  *
  *       Conversion tools Library using Walpole notations      *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.4.0                   *
+ *	             GNU/linux version 2.6.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2009 COLLARD Christophe
  * copyright © 2009 BERBENNI Stephane
+ * copyright © 2009 Centre National de la Recherche Scientifique
+ * copyright © 2009 Arts et Métiers ParisTech
  * copyright © 2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  ***************************************************************/
 
@@ -42,9 +44,11 @@
 
     \author copyright \htmlonly &#169; \endhtmlonly 2009 Christophe COLLARD \n
             copyright \htmlonly &#169; \endhtmlonly 2009 Stephane BERBENNI \n
+            copyright \htmlonly &#169; 2009 Centre National de la Recherche Scientifique \endhtmlonly \n
+	    copyright \htmlonly &#169; 2009 Arts et M&#233;tiers ParisTech \endhtmlonly \n
 	    copyright \htmlonly &#169; 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
-    \version 2.4.0
-    \date 2010
+    \version 2.6.0
+    \date 2009-2011
     \bug none
     \warning none
 */
