@@ -1,10 +1,13 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.4.0                   *
+ *	             GNU/linux version 2.6.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
- * copyright © 2003,2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2003,2004,2005,2006,2007,2008,2009,2010 COLLARD Christophe
+ * copyright © 2003,2004,2005,2006,2007,2008,2009,2010 Centre National de la Recherche Scientifique
+ * copyright © 2003,2004,2005,2006,2007,2008,2009,2010 Arts et Métiers ParisTech
+ * copyright © 2003,2004,2005,2006,2007 Université de Valenciennes et du Hainaut-Cambrésis
+ * copyright © 2003,2004,2005,2006,2007,2008,2009,2010 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
@@ -281,7 +284,7 @@ int test_isotropic_elasticity_tensor (int detail)
 		  tsr(p,q,m,n) += P(p,i) * P(q,j) * P(m,k) * P(n,l) * C(i,j,k,l);
   long double scalar = .1;
   test = true;
-  test *= (C == change_basis(passlg,C,true));
+  test *= (C == change_orthonormal_basis(passlg,C));
   test *= (C*scalar == change_basis(passlg,C)*scalar);
   test *= (tsr == change_basis(P,C));
   if (detail) affiche ("change basis", test);
@@ -294,6 +297,9 @@ int test_isotropic_elasticity_tensor (int detail)
   if (detail) affiche ("cast conversion : tensor4 -> isotropic_elasticity_tensor", TC==C && TC.Lame()==lambda && TC.Shear()==mu);
   else result *=  (TC==C && TC.Lame()==lambda && TC.Shear()==mu);
 
+  //  if (detail) affiche ("cast conversion : symtensor4 -> isotropic_elasticity_tensor", TC==C && TC.Lame()==lambda && TC.Shear()==mu);
+  //  else result *=  (TC==C && TC.Lame()==lambda && TC.Shear()==mu);
+
   isotropic_tensor<long double> Ti;
   isotropic_elasticity_tensor<long double> Tie;
   Ti.lambda(60000);
