@@ -1,11 +1,14 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.4.0                   *
+ *	             GNU/linux version 2.6.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2003,2004,2005,2006,2007,2008,2009,2010 COLLARD Christophe
  * copyright © 2006 PARGUEZ Cristelle
- * copyright © 2003,2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2003,2004,2005,2006,2007,2008,2009,2010 Centre National de la Recherche Scientifique
+ * copyright © 2003,2004,2005,2006,2007,2008,2009,2010 Arts et Métiers ParisTech
+ * copyright © 2003,2004,2005,2006,2007 Université de Valenciennes et du Hainaut-Cambrésis
+ * copyright © 2003,2004,2005,2006,2007,2008,2009,2010 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
@@ -52,22 +55,26 @@
 #include "parameters.h"
 #endif
 
-#if !defined(___COLORS_H)
+#if !defined(__COLORS_H)
 #include "colors.h"
 #endif
 
-#if !defined(___VECTORS_H)
+#if !defined(__VECTORS_H)
 #include "MOL++/vectors.h"
 #endif
 
-#if !defined(___MATRIX_H)
+#if !defined(__MATRIX_H)
 #include "MOL++/matrix.h"
 #endif
 
-#if !defined(___TENSOR4_H)
+#if !defined(__TENSOR4_H)
 #include "MOL++/tensors4.h"
 #endif
 
+#if !defined(__SYMTENSOR4_H)
+#include "MOL++/symtensors4.h"
+#endif
+
 #if !defined(__ISOTROPIC_TENSORS_H)
 #include "MateriOL++/isotropic tensors.h"
 #endif
@@ -128,27 +135,28 @@ int test_isotropic_tensor (int detail)
   if (detail) affiche ("cast operator () isotropic_tensor -> tensor4", test);
   else result *= (test);
 
+  symtensor4<long double> ST;
+  ST  = C;
+  if (detail) affiche ("cast operator () isotropic_tensor -> symtensor4", ST == T);
+  else result *= (ST==T);
 
-  isotropic_tensor <long double> C3(2000,3000),C4(4572,5507);
-  tensor4 <long double> T3,T4;
-  T3=C3;
-  T4=C4;
+  isotropic_tensor <long double> C3(2000,3000), C4(4572,5507);
+  tensor4 <long double> T3, T4;
+  T3 = C3;
+  T4 = C4;
 
   test = (C3==C3) && !(C3==C4);
   if (detail) affiche ("operator ==", test);
   else result *= (test);
 
-
   test = (C3==T3) && !(C3==T4);
   if (detail) affiche ("operator == (isotropic_tensor/tensor4)", test);
   else result *= (test);
 
-
   test = (T3==C3) && !(T3==C4);
   if (detail) affiche ("operator == (tensor4/isotropic_tensor)", test);
   else result *= (test);
 
-
   for (int i=1; i<=3; i++)
     for (int j=1; j<=3; j++)
       for (int k=1; k<=3; k++)
@@ -168,20 +176,17 @@ int test_isotropic_tensor (int detail)
   if (detail) affiche ("constructors", test);
   else result *= (test);
 
-
   isotropic_tensor<long double> iso(C3);
   test *= (iso == C3);
   if (detail) affiche ("copy constructor", test);
   else result *= (test);
 
-
   isotropic_tensor<long double> R1(50000,6000,"isotropic tensor"), R2(20000,60000);
   R2.name("isotropic");
   test *= ((R1.name() == "isotropic tensor") && (R2.name() == "isotropic"));
   if (detail) affiche ("name", test);
   else result *= (test);
 
-
   tensor4<long double> Tsr(3,3,3,3);
   isotropic_tensor<long double> Iso(5000,8000);
   Tsr=Iso;
@@ -191,6 +196,12 @@ int test_isotropic_tensor (int detail)
   if (detail) affiche ("cast convertion tensor4 -> isotropic_tensor", Iso==Iso1 && Iso==Iso2 );
   else result *= (Iso==Iso1 && Iso==Iso2 );
 
+  tensor4<long double> STsr(3,3,3,3);
+  Tsr=Iso;
+  isotropic_tensor<long double> Iso3;
+  Iso3=Tsr;
+  if (detail) affiche ("cast convertion tensor4 -> isotropic_tensor", Iso==Iso3);
+  else result *= (Iso==Iso3);
 
   test = (Ct == C);
   test *= (C.mu()== mu && C.lambda() == lambda);
@@ -202,7 +213,6 @@ int test_isotropic_tensor (int detail)
   if (detail) affiche ("lambda", test);
   else result *= (test);
 
-
   mu *= 3;
   isotropic_tensor<long double> I2(lambda,mu);
   C0.mu(mu);
@@ -211,9 +221,12 @@ int test_isotropic_tensor (int detail)
   else result *= (test);
 
 
-//tests des operateurs
+  //===============
+  // operator tests
+  //===============
 
-  isotropic_tensor<long double> c1(0,2000),c2(5000,0),c3(0,0);
+
+  isotropic_tensor<long double> c1(0,2000), c2(5000,0), c3(0,0);
   test *= (!C3 == false) && (!c1 == true) && (!c2 == true) && (!c3 == true);
   if (detail) affiche ("operator !", test);
   else result *= (test);
@@ -229,31 +242,26 @@ int test_isotropic_tensor (int detail)
   if (detail) affiche ("operator []", T[1] == C[1]);
   else result *= (T[1] == C[1]);
 
-
   test = (T3==C3 && T4==C4);
   test *= T3+T4 == C3+C4;
   if (detail) affiche ("operator +", test);
   else result *= (test);
 
-
   test = (T3==C3 && T4==C4);
   test *= T3-T4 == C3-C4;
   if (detail) affiche ("operator -", test);
   else result *= (test);
 
-
   test = (T3==C3 && T4==C4);
   test *= (T3|T4) == (C3|C4);
   if (detail) affiche ("operator |", test);
   else result *= (test);
 
-
   test = (T3==C3 && T4==C4);
   test *= (T3||T4) == (C3||C4);
   if (detail) affiche ("operator ||", test);
   else result *= (test);
 
-
   test = (T3==C3 && T4==C4);
   C3+=C4;
   T3+=T4;
@@ -261,7 +269,6 @@ int test_isotropic_tensor (int detail)
   if (detail) affiche ("operator +=", test);
   else result *= (test);
 
-
   test = (T3==C3 && T4==C4);
   C3-=C4;
   T3-=T4;
@@ -269,24 +276,26 @@ int test_isotropic_tensor (int detail)
   if (detail) affiche ("operator -=", test);
   else result *= (test);
 
-
   test = !(C3!=C3) && (C3!=C4);
   if (detail) affiche ("operator !=", test);
   else result *= (test);
 
 
+  //========================
+  // operations with scalars
+  //========================
+
+
   test = (T3==C3);
   test *= (T3*(long double)5) == (C3*(long double)5);
   if (detail) affiche ("operator * (isotropic_tensor/scalar)", test);
   else result *= (test);
 
-
   test = (T3==C3);
   test *= ((long double)3*T3) == ((long double)3*C3);
   if (detail) affiche ("operator * (scalar/isotropic_tensor)", test);
   else result *= (test);
 
-
   test = (T3==C3);
   C3*=2;
   T3*=2;
@@ -295,6 +304,11 @@ int test_isotropic_tensor (int detail)
   else result *= (test);
 
 
+  //========================
+  // operations with vectors
+  //========================
+
+
   vector<long double> v(3);
   for (int k=1; k<=3; k++) v[k] = 0.125*k;
   v[2] -= 2;
@@ -304,31 +318,31 @@ int test_isotropic_tensor (int detail)
   if (detail) affiche ("operator * (isotropic_tensor/vector)", test);
   else result *= (test);
 
-
   test = (T3==C3);
   test *= (v*C3)==(v*T3);
   if (detail) affiche ("operator * (vector/isotropic_tensor)", test);
   else result *= (test);
 
-
   test = (T3==C3);
   test *= (C3|v)==(T3|v);
   if (detail) affiche ("operator | (isotropic_tensor/vector)", test);
   else result *= (test);
 
-
   test = (T3==C3);
   test *= (v|C3)==(v|T3);
   if (detail) affiche ("operator | (vector/isotropic_tensor)", test);
   else result *= (test);
 
-
   test = (T3==C3);
   test *= (tensor_sum(C3,v,1) == tensor_sum(T3,v,1))  &&  (tensor_sum(C3,v,2) == tensor_sum(T3,v,2))  &&  (tensor_sum(C3,v,3) == tensor_sum(T3,v,3)) &&  (tensor_sum(C3,v,4) == tensor_sum(T3,v,4));
   if (detail) affiche ("sum tensor * vector (i), i = 1->4 :", test);
   else result *= (test);
 
 
+  //=================================
+  // operation with 2nd order tensors
+  //=================================
+
 
   tensor2<long double> t2s(3,3,false);
   for (int i=1; i<=3; i++)
@@ -340,13 +354,17 @@ int test_isotropic_tensor (int detail)
   if (detail) affiche ("operator || (isotropic_tensor/tenor2)", test);
   else result *= (test);
 
-
   test = (T3==C3);
   test *= (t2s||C3)==(t2s||T3);
   if (detail) affiche ("operator || (tensor2/isotropic_tensor)", test);
   else result *= (test);
 
 
+  //=================================
+  // operation with 3rd order tensors
+  //=================================
+
+
   tensor3<long double> t3s(3,3,3,false);
   for (int i=1; i<=3; i++)
     for (int j=1; j<=3; j++)
@@ -358,79 +376,121 @@ int test_isotropic_tensor (int detail)
   if (detail) affiche ("operator || (isotropic_tensor/tensor3)", test);
   else result *= (test);
 
-
   test = (T3==C3);
   test *= (t3s||C3)==(t3s||T3);
   if (detail) affiche ("operator || (tensor3/isotropic_tensor)", test);
   else result *= (test);
 
-  tensor4<long double> t4s(3,3,3,3,false);
+
+  //=================================
+  // operation with 4th order tensors
+  //=================================
+
+
+  tensor4<long double> t4s (3,3,3,3,false);
   for (int i=1; i<=3; i++)
     for (int j=1; j<=3; j++)
       for (int k=1; k<=3; k++)
         for (int l=1; l<=3; l++)
-	t4s(i,j,k,l) = 3*k/i + 2*j/k -l;
-  t4s[2]=t3s;
+	t4s(i,j,k,l) = 3*k/i + 2*j/k - l;
+  t4s[2] = t3s;
 
   test = (T4==C4);
   test *= C4+t4s == T4+t4s;
   if (detail) affiche ("operator + (isotropic_tensor/tensor4)", test);
   else result *= (test);
 
-
   test = (T4==C4);
   test *= t4s+C4 == t4s+T4;
   if (detail) affiche ("operator + (tensor4/isotropic_tensor)", test);
   else result *= (test);
 
-
   test = (T4==C4);
   test *= C4-t4s == T4-t4s;
   if (detail) affiche ("operator - (isotropic_tensor/tensor4)", test);
   else result *= (test);
 
-
   test = (T4==C4);
   test *= t4s-C4 == t4s-T4;
   if (detail) affiche ("operator - (tensor4/isotropic_tensor)", test);
   else result *= (test);
 
-
   test = (T4==C4);
   test *= (C4|t4s) == (T4|t4s);
   if (detail) affiche ("operator | (isotropic_tensor/tensor4)", test);
   else result *= (test);
 
-
   test = (T4==C4);
   test *= (t4s|C4) == (t4s|T4);
   if (detail) affiche ("operator | (tensor4/isotropic_tensor)", test);
   else result *= (test);
 
-
   test = (T4==C4);
   test *= (C4||t4s) == (T4||t4s);
   if (detail) affiche ("operator || (isotropic_tensor/tensor4)", test);
   else result *= (test);
 
-
   test = (T4==C4);
   test *= (t4s||C4) == (t4s||T4);
   if (detail) affiche ("operator || (tensor4/isotropic_tensor)", test);
   else result *= (test);
 
-
   test = (T3==C3);
   test = !(C3!=T3) && (C3!=t4s);
   if (detail) affiche ("operator != (isotropic_tensor/tensor4)", test);
   else result *= (test);  
 
-
   test = (T3==C3);
   test = !(T3!=C3) && (t4s!=C3);
   if (detail) affiche ("operator != (tensor4/isotropic_tensor)", test);
   else result *= (test);
 
+
+  //===========================
+  // operations with symtensor4
+  //===========================
+
+
+  symtensor4<long double> ST4 (3);
+  for (int i=1; i<=3; i++)
+    for (int j=i; j<=3; j++)
+      for (int k=1; k<=3; k++)
+	for (int l=k; l<=3; l++)
+	  ST4 (i,j,k,l) = 2 * (i + j) / (k * l);
+  if (detail) affiche ("operator + (isotropic_tensor/symtensor4)", T4+ST4 == C4+ST4);
+  else result *= (T4+ST4 == C4+ST4);
+
+  if (detail) affiche ("operator + (symtensor4/isotropic_tensor)", T4+ST4 == ST4+C4);
+  else result *= (T4+ST4 == ST4+C4);
+
+  if (detail) affiche ("operator - (isotropic_tensor/symtensor4)", T4-ST4 == C4-ST4);
+  else result *= (T4-ST4 == C4-ST4);
+
+  if (detail) affiche ("operator - (symtensor4/isotropic_tensor)", ST4-T4 == ST4-C4);
+  else result *= (ST4-T4 == ST4-C4);
+
+  if (detail) affiche ("operator | (isotropic_tensor/symtensor4)", (T4|ST4) == (C4|ST4));
+  else result *= ((T4|ST4) == (C4|ST4));
+
+  if (detail) affiche ("operator | (symtensor4/isotropic_tensor)", (ST4|T4) == (ST4|C4));
+  else result *= ((ST4|T4) == (ST4|C4));
+
+  if (detail) affiche ("operator || (isotropic_tensor/symtensor4)", (T4||ST4) == (C4||ST4));
+  else result *= ((T4||ST4) == (C4||ST4));
+
+  if (detail) affiche ("operator || (symtensor4/isotropic_tensor)", (ST4||T4) == (ST4||C4));
+  else result *= ((ST4||T4) == (ST4||C4));
+
+  symtensor4<long double> ST44 = C4;
+  test = !(C4!=ST44) && (C4!=ST4);
+  if (detail) affiche ("operator == != (isotropic_tensor/symtensor4)", test);
+  else result *= (test);  
+
+  test = !(ST44!=C4) && (ST4!=C4);
+  if (detail) affiche ("operator == != (symtensor4/isotropic_tensor)", test);
+  else result *= (test);
+
+
   S = C0;
   S.name("stiffness tensor");
   S.lambda(-1.*lambda/(2*mu)/(3*lambda+2*mu));
@@ -470,7 +530,7 @@ int test_isotropic_tensor (int detail)
 		  tsr(p,q,m,n) += P(p,i) * P(q,j) * P(m,k) * P(n,l) * C(i,j,k,l);
   long double scalar = .01;
   test = true;
-  test *= (C == change_basis(passlg,C,true));
+  test *= (C == change_orthonormal_basis(passlg,C));
   test *= (C*scalar == change_basis(passlg,C)*scalar);
   test *= (tsr == change_basis(P,C));
   if (detail) affiche ("change basis", test);
