@@ -1,11 +1,15 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.4.0                   *
+ *	             GNU/linux version 2.6.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2009 COLLARD Christophe
+ * copyright © 2009,2011 COLLARD Christophe
  * copyright © 2009 BERBENNI Stephane
+ * copyright © 2009,2011 Centre National de la Recherche Scientifique
+ * copyright © 2009,2011 Arts et Métiers ParisTech
  * copyright © 2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2011 Laboratoire d'Etude des Microstructures et de Mécanique des Matériaux (LEM3 - CNRS)
+ * copyright © 2011 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*
@@ -47,7 +51,7 @@
 #include <stdlib.h>
 #endif
 
-#if !defined(___COLORS_H)
+#if !defined(__COLORS_H)
 #include "colors.h"
 #endif
 
@@ -55,15 +59,19 @@
 #include "parameters.h"
 #endif
 
-#if !defined(___MATHS_H)
+#if !defined(__MATHS_H)
 #include "MOL++/maths.h"
 #endif
 
-#if !defined(___VECTORS_H)
+#if !defined(__VECTORS_H)
 #include "MOL++/vectors.h"
 #endif
 
-#if !defined(___TENSOR2_H)
+#if !defined(__MATRIX_H)
+#include "MOL++/matrix.h"
+#endif
+
+#if !defined(__TENSOR2_H)
 #include "MOL++/tensors2.h"
 #endif
 
@@ -71,7 +79,7 @@
 #include "MOL++/symtensors2.h"
 #endif
 
-#if !defined(___TENSOR4_H)
+#if !defined(__TENSOR4_H)
 #include "MOL++/tensors4.h"
 #endif
 
@@ -173,6 +181,9 @@ bool test_transversely_isotropic_tensor (int detail)
   tensor4<long double> T = change_basis (P,C);
   //  cout << symtensor2matrix (T);
 
+  if (detail) affiche ("inv", (Ciso_tr || Ciso_tr.inv()) == Id4s<long double>(3));
+  else result *= ( (Ciso_tr || Ciso_tr.inv()) == Id4s<long double>(3));
+
   if (detail) affiche ("change basis", Cnew == T);
   else result *= (Cnew == T);
 
